Welcome to Camelot’s documentation! — Camelot documentation

### Navigation

- index
- modules |
- next |
- Camelot documentation »

# Welcome to Camelot’s documentation!

Release: | trunk
Date: | November 03, 2011

- What’s new

Contents:

- Tutorials
  - Creating a Movie Database Application
  - Creating a Report with Camelot
  - Add an import wizard to an application
- Camelot Documentation
  - Camelot Installation
  - Creating models
  - Customizing the Admin classes
  - Customizing the Application
  - Creating Forms
  - Actions
  - Documents and Reports
  - Delegates
  - Charts
  - Document Management
  - Build in data models
  - Fixtures : handling static data in the database
  - Managing a Camelot project
  - Schema Revisions and Migrations
  - Camelot Shortcuts
  - The Two Threads
  - Frequently Asked Questions
- Camelot API
  - admin
  - art
  - bin
  - container
  - core
  - model
  - test
  - types
  - view
- Advanced Topics
  - Internationalization
  - Unittests
  - Deployment
  - Authentication and permissions
  - Development Guidlines
  - Debugging Camelot and PyQt
- Camelot Enhancement Proposals
  - New Actions

# Support

## Community

Community support is available on the mailing list.

## Commercial

Commercial support and training is available from Conceptive Engineering, the main authors of Camelot :

Conceptive Engineering
L Van Bauwelstraat 16
2222 Heist-op-den-Berg
Belgium
project-camelot@conceptive.be
http://www.conceptive.be
VAT BE 0878 169 209
Fax : +32 3 303 64 41

Priority support tickets can be purchased from the shop. Please contact us for support contracts.

Indices and tables:

- Index
- Module Index
- Search Page

Others:

- Complete Table of Contents
  - Tutorials
  - Camelot Documentation
  - Advanced Topics
  - Camelot, Qt, PyQt Licenses
  - GNU GENERAL PUBLIC LICENSE TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
  - Camelot’s Documentation Copyright
- Camelot, Qt, PyQt Licenses
  - Camelot License
- GNU GENERAL PUBLIC LICENSE TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
  - PyQt License
  - Qt License
- Camelot’s Documentation Copyright

### Navigation

- index
- modules |
- next |
- Camelot documentation »

Comments
blog comments powered by Disqus